@@ -1,8 +1,8 @@
 # OTHERS
-import time, logging, abc, os
+import time, logging, abc, os, threading
 from random import randrange, randint
 from functools import wraps
-from typing import TYPE_CHECKING, Union, Optional
+from typing import TYPE_CHECKING, Union, Optional, List
 
 # SELENIUM STUFF
 from selenium import webdriver
@@ -18,5 +18,17 @@ from selenium.webdriver.support import expected_conditions as EC
 # INSTACLIENT PACKAGE
 from instaclient import LOGGER
 from instaclient.client.constants import (ClientUrls, GraphUrls, Paths)
-from instaclient.errors.common import *
-from instaclient.instagram import *
\ No newline at end of file
+from instaclient.errors import *
+
+from instaclient.instagram import (
+    InstaBaseObject,
+    Comment,
+    Post,
+    Profile,
+    Hashtag,
+    Location,
+    Address,
+    PostMedia,
+    Notification
+)
+    
\ No newline at end of file
