@@ -42,7 +42,7 @@ class Paths:
     # ENGAGEMENT PROCEDURES
     # Post Interactions
     COMMENT_TEXT_AREA = '//textarea[@class="Ypffh"]'
-    SEND_COMMENT_BTN = '//button[@="sqdOP yWX7d    y3zKF     "]'
+    SEND_COMMENT_BTN = '//button[@class="sqdOP yWX7d    y3zKF     "]'
     LIKE_BTN = '//span[@class="fr66n"]'
     COMMENT_BTN = '//span[@class="_15y0l"]'
 
@@ -50,7 +50,7 @@ class Paths:
     FOLLOW_BTN = '//button[@class="sqdOP  L3NKy _4pI4F  y3zKF     " or @class="_5f5mN       jIbKX  _6VtSN     yZn4P   "]'
     UNFOLLOW_BTN = '//button[@class="_5f5mN    -fzfL     _6VtSN     yZn4P   "]//descendant::span'
     CONFIRM_UNFOLLOW_BTN = '//button[@class="aOOlW -Cab_   "]'
-    REQUESTED_BTN = '//dic[@class=" ffKix "]//descendant::button'
+    REQUESTED_BTN = '//div[@class=" ffKix "]//descendant::button'
     MESSAGE_USER_BTN = '//button[@class="sqdOP  L3NKy _4pI4F   _8A5w5    "]'
     
     # USER ACCOUNT DMs PAGE
