@@ -147,8 +147,8 @@ class InstaClient(Auth, Interactions, Scraper):
         return super()._scrape_profile(username, context=context)
 
 
-    def get_followers(self, user: str, count: int, check_user:bool=True, callback_frequency: int=100, callback=None, **callback_args) -> Optional[list]:
-        return super()._scrape_followers(user, count, check_user=check_user, callback_frequency=callback_frequency, callback=callback, **callback_args)
+    def get_followers(self, user: str, count: int, deep_scrape:bool=False, check_user:bool=True, callback_frequency: int=100, callback=None, **callback_args) -> Optional[list]:
+        return super()._scrape_followers(user, count, deep_scrape=deep_scrape, check_user=check_user, callback_frequency=callback_frequency, callback=callback, **callback_args)
 
     
     def get_post(self, shortcode:int, context:Optional[bool]=True) -> Optional[Post]:
@@ -178,16 +178,14 @@ class InstaClient(Auth, Interactions, Scraper):
 
 
     def comment_post(self, shortcode: str, text: str) -> Optional[Comment]:
-        result = super()._comment_on_post(shortcode, text)
-        # Return Comment Object
-        return self._find_comment(shortcode, self.username, text)
-
+        return super()._comment_on_post(shortcode, text)
 
     def like_post(self, shortcode: str) -> Optional[Post]:
-        if super()._like_post(shortcode):
-            return self._scrape_post(shortcode)
-        else:
-            return None
+        return super()._like_post(shortcode=shortcode)
+
+    
+    def unlike_post(self, shortocde: str) -> Optional[Post]:
+        return super()._unlike_post(shortcode=shortocde)
 
 
     def like_user_posts(self, user: str, n_posts: int, like: bool=True):
